@@ -167,6 +167,11 @@ NvBool nvkms_enable_overlay_layers(void)
     return NV_TRUE;
 }
 
+NvBool nvkms_debug_logging(void)
+{
+    return NV_FALSE;
+}
+
 /*************************************************************************
  * Used for queueing nvkms events. We do not use the nvkms timer abstraction
  * since it locks nvkms_lock
@@ -637,8 +642,9 @@ nvkms_event_queue_changed(nvkms_per_open_handle_t *pOpenKernel,
 
 static nvidia_modeset_rm_ops_t __rm_ops = { 0 };
 static nvidia_modeset_callbacks_t nvkms_rm_callbacks = {
-    nvkms_suspend,
-    nvkms_resume
+    .suspend = nvkms_suspend,
+    .resume = nvkms_resume,
+    /* TODO: Support hotplugging/unplugging of NVIDIA modeset clients through RM */
 };
 
 static int nvkms_alloc_rm(void)
