@@ -1231,6 +1231,14 @@ NV_STATUS NV_API_CALL os_get_random_bytes
     return NV_OK;
 }
 
+NvU32 NV_API_CALL os_get_current_process_flags
+(
+    void
+)
+{
+    return OS_CURRENT_PROCESS_FLAG_NONE;
+}
+
 NV_STATUS NV_API_CALL os_alloc_wait_queue
 (
     os_wait_queue **wq
