@@ -1,6 +1,6 @@
 /* _NVRM_COPYRIGHT_BEGIN_
  *
- * Copyright 2001-2024 by NVIDIA Corporation.  All rights reserved.  All
+ * Copyright 2001-2025 by NVIDIA Corporation.  All rights reserved.  All
  * information contained herein is proprietary and confidential to NVIDIA
  * Corporation.  Any use, reproduction, or disclosure without the written
  * permission of NVIDIA Corporation is prohibited.
@@ -180,7 +180,7 @@ int nvidia_alloc_hardware(device_t dev)
     struct nvidia_softc *sc;
     NvU32 flags, i;
     NvU32 enable_msi = 0;
-    int count;
+    int count, msi;
     nvidia_stack_t *sp;
 
     NV_UMA_ZONE_ALLOC_STACK(sp);
@@ -212,7 +212,13 @@ int nvidia_alloc_hardware(device_t dev)
     if ((rm_read_registry_dword(sp, NULL,
             "EnableMSI", &enable_msi) == NV_OK) && (enable_msi != 0)) {
         count = pci_msi_count(dev);
-        if ((count == 1) && (pci_alloc_msi(dev, &count) == 0))
+        /*
+         * The count may be greater than zero but we only want to allocate one
+         * interrupt when we call pci_alloc_msi. Each MSI will be available to
+         * the driver as SYS_RES_IRQ resources starting at a rid 1.
+         */
+        msi = 1;
+        if ((count > 0) && (pci_alloc_msi(dev, &msi) == 0))
             sc->irq_rid = 1;
     }
     flags = RF_SHAREABLE | RF_ACTIVE;
@@ -906,7 +912,7 @@ void* NV_API_CALL nv_alloc_kernel_mapping(
     return (void *)(virtual_address + pageOffset);
 }
 
-NV_STATUS NV_API_CALL nv_free_kernel_mapping(
+void NV_API_CALL nv_free_kernel_mapping(
     nv_state_t *nv,
     void       *pAllocPrivate,
     void       *address,
@@ -922,8 +928,6 @@ NV_STATUS NV_API_CALL nv_free_kernel_mapping(
         vm_map_remove(kernel_map, virtual_address,
             (virtual_address + size));
     }
-
-    return NV_OK;
 }
 
 nv_file_private_t* NV_API_CALL nv_get_file_private(
@@ -1048,7 +1052,6 @@ NV_STATUS NV_API_CALL nv_add_mapping_context_to_file(
 
         nvamc->access_start = nvuap->access_start;
         nvamc->access_size = nvuap->access_size;
-        nvamc->remap_prot_extra = nvuap->remap_prot_extra;
     }
 
     nvamc->prot = prot;
@@ -1083,14 +1086,13 @@ NV_STATUS NV_API_CALL nv_alloc_user_mapping(
     return NV_OK;
 }
 
-NV_STATUS NV_API_CALL nv_free_user_mapping(
+void NV_API_CALL nv_free_user_mapping(
     nv_state_t *nv,
     void       *pAllocPrivate,
     NvU64       userAddress,
     void       *pPrivate
 )
 {
-    return NV_OK;
 }
 
 #ifdef NV_USE_WBINVD
@@ -1711,6 +1713,16 @@ NV_STATUS NV_API_CALL nv_dma_map_peer(
     return NV_ERR_NOT_SUPPORTED;
 }
 
+NV_STATUS NV_API_CALL nv_dma_map_non_pci_peer
+(
+    nv_dma_device_t *dma_dev,
+    NvU64            page_count,
+    NvU64           *va
+)
+{
+    return NV_ERR_NOT_SUPPORTED;
+}
+
 void NV_API_CALL nv_dma_unmap_peer(
     nv_dma_device_t *dma_dev,
     NvU64            page_count,
@@ -1778,7 +1790,8 @@ NV_STATUS NV_API_CALL nv_register_user_pages(
     NvU64       page_count,
     NvU64      *phys_addr,
     void       *import_priv,
-    void      **priv
+    void      **priv,
+    NvBool      unencrypted
 )
 {
     NvU64 i;
@@ -1867,9 +1880,9 @@ NV_STATUS NV_API_CALL nv_get_egm_info(
     return NV_ERR_NOT_SUPPORTED;
 }
 
-NV_STATUS NV_API_CALL nv_get_usermap_access_params(
+NV_STATUS NV_API_CALL nv_check_usermap_access_params(
     nv_state_t *nv,
-    nv_usermap_access_params_t *nvuap
+    const nv_usermap_access_params_t *nvuap
 )
 {
     return NV_OK;
@@ -1899,7 +1912,8 @@ NV_STATUS NV_API_CALL nv_register_sgt(
     NvU32       cache_type,
     void      **priv_data,
     struct sg_table *import_sgt,
-    void       *import_priv
+    void       *import_priv,
+    NvBool      is_peer_mmio
 )
 {
     return NV_OK;
@@ -2106,6 +2120,7 @@ NV_STATUS NV_API_CALL nv_dma_import_dma_buf
 (
     nv_dma_device_t *dma_dev,
     struct dma_buf *dma_buf,
+    NvBool is_ro_device_map,
     NvU32 *size,
     struct sg_table **sgt,
     nv_dma_buf_t **import_priv
@@ -2118,6 +2133,7 @@ NV_STATUS NV_API_CALL nv_dma_import_from_fd
 (
     nv_dma_device_t *dma_dev,
     NvS32 fd,
+    NvBool is_ro_device_map,
     NvU32 *size,
     struct sg_table **sgt,
     nv_dma_buf_t **import_priv
@@ -2243,6 +2259,34 @@ void NV_API_CALL nv_put_firmware(
     if (fw_handle != NULL)
         firmware_put(fw_handle, FIRMWARE_UNLOAD);
 }
+NvBool NV_API_CALL nv_pci_tegra_register_power_domain (
+    nv_state_t *nv,
+    NvBool attach
+)
+{
+    return NV_TRUE;
+}
+
+NvBool NV_API_CALL nv_pci_tegra_pm_init (
+    nv_state_t *nv
+)
+{
+    return NV_TRUE;
+}
+
+void NV_API_CALL nv_pci_tegra_pm_deinit (
+    nv_state_t *nv
+)
+{
+}
+
+NvBool NV_API_CALL nv_grdma_pci_topology_supported (
+    nv_state_t *nv,
+    nv_dma_device_t *dma_peer
+)
+{
+    return NV_FALSE;
+}
 
 NvBool NV_API_CALL nv_is_chassis_notebook(void)
 {
@@ -2398,6 +2442,164 @@ NV_STATUS nv_get_syncpoint_aperture
     NvU64 *limit,
     NvU32 *offset
 )
+{
+   return NV_ERR_NOT_SUPPORTED;
+}
+
+NV_STATUS NV_API_CALL nv_clk_get_handles
+(
+    nv_state_t *nv
+)
 {
     return NV_ERR_NOT_SUPPORTED;
 }
+
+void NV_API_CALL nv_clk_clear_handles
+(
+    nv_state_t *nv
+)
+{
+    return;
+}
+
+NV_STATUS NV_API_CALL nv_enable_clk
+(
+    nv_state_t *nv,
+    TEGRASOC_WHICH_CLK whichClkOS
+)
+{
+    return NV_ERR_NOT_SUPPORTED;
+}
+
+void NV_API_CALL nv_disable_clk
+(
+    nv_state_t *nv,
+    TEGRASOC_WHICH_CLK whichClkOS
+)
+{
+    return;
+}
+
+NV_STATUS NV_API_CALL nv_get_curr_freq
+(
+    nv_state_t *nv,
+    TEGRASOC_WHICH_CLK whichClkOS,
+    NvU32 *pCurrFreqKHz
+)
+{
+    return NV_ERR_NOT_SUPPORTED;
+}
+
+NV_STATUS NV_API_CALL nv_get_max_freq
+(
+    nv_state_t *nv,
+    TEGRASOC_WHICH_CLK whichClkOS,
+    NvU32 *pMaxFreqKHz
+)
+{
+    return NV_ERR_NOT_SUPPORTED;
+}
+
+NV_STATUS NV_API_CALL nv_get_min_freq
+(
+    nv_state_t *nv,
+    TEGRASOC_WHICH_CLK whichClkOS,
+    NvU32 *pMinFreqKHz
+)
+{
+    return NV_ERR_NOT_SUPPORTED;
+}
+
+NV_STATUS NV_API_CALL nv_set_freq
+(
+    nv_state_t *nv,
+    TEGRASOC_WHICH_CLK whichClkOS,
+    NvU32 freqKHz
+)
+{
+    return NV_ERR_NOT_SUPPORTED;
+}
+
+NV_STATUS NV_API_CALL
+nv_bpmp_send_mrq
+(
+    nv_state_t *nv,
+    NvU32       mrq,
+    const void *request_data,
+    NvU32       request_data_size,
+    void       *response_data,
+    NvU32       response_data_size,
+    NvS32      *ret,
+    NvS32      *api_ret
+)
+{
+    return NV_ERR_NOT_SUPPORTED;
+}
+
+NV_STATUS NV_API_CALL
+nv_imp_get_import_data
+(
+    TEGRA_IMP_IMPORT_DATA *tegra_imp_import_data
+)
+{
+    return NV_ERR_NOT_SUPPORTED;
+}
+
+NV_STATUS NV_API_CALL
+nv_imp_enable_disable_rfl
+(
+    nv_state_t *nv,
+    NvBool bEnable
+)
+{
+    return NV_ERR_NOT_SUPPORTED;
+}
+
+NV_STATUS NV_API_CALL
+nv_imp_icc_set_bw
+(
+    nv_state_t *nv,
+    NvU32       avg_bw_kbps,
+    NvU32       floor_bw_kbps
+)
+{
+    return NV_ERR_NOT_SUPPORTED;
+}
+
+NV_STATUS NV_API_CALL nv_get_num_dpaux_instances(nv_state_t *nv, NvU32 *num_instances)
+{
+    return NV_ERR_NOT_SUPPORTED;
+}
+
+NV_STATUS NV_API_CALL nv_get_current_irq_priv_data(nv_state_t *nv, NvU32 *priv_data)
+{
+    return NV_ERR_NOT_SUPPORTED;
+}
+
+NV_STATUS NV_API_CALL nv_get_tegra_brightness_level
+(
+    nv_state_t *nv,
+    NvU32 *brightness
+)
+{
+    return NV_ERR_NOT_SUPPORTED;
+}
+
+NV_STATUS NV_API_CALL nv_set_tegra_brightness_level
+(
+    nv_state_t *nv,
+    NvU32 brightness
+)
+{
+    return NV_ERR_NOT_SUPPORTED;
+}
+
+NV_STATUS NV_API_CALL os_iommu_sva_bind(void *arg, void **handle, NvU32 *pasid)
+{
+    return NV_ERR_NOT_SUPPORTED;
+}
+
+void NV_API_CALL os_iommu_sva_unbind(void *handle)
+{
+    return;
+}
